bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.plates_from_parent
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.plates_from_parent